@@ -99,6 +99,9 @@ struct _EmpathyChatPriv {
 	gulong		   delete_range_id;
 	gulong		   notify_cursor_position_id;
 
+	/* Source func ID for update_misspelled_words () */
+	guint              update_misspelled_words_id;
+
 	GtkWidget         *widget;
 	GtkWidget         *hpaned;
 	GtkWidget         *vbox_left;
@@ -228,18 +231,11 @@ chat_set_property (GObject      *object,
 }
 
 static void
-reconnected_connection_ready_cb (TpConnection *connection,
-			const GError *error,
-			gpointer user_data)
+account_reconnected (EmpathyChat *chat,
+			TpAccount *account)
 {
-	EmpathyChat *chat = user_data;
 	EmpathyChatPriv *priv = GET_PRIV (chat);
 
-	if (error != NULL) {
-		DEBUG ("connection is not ready: %s", error->message);
-		goto out;
-	}
-
 	DEBUG ("Account reconnected, request a new Text channel");
 
 	/* FIXME: Ideally we should ask to handle ourself the channel so we can
@@ -248,19 +244,20 @@ reconnected_connection_ready_cb (TpConnection *connection,
 	switch (priv->handle_type) {
 		case TP_HANDLE_TYPE_CONTACT:
 			empathy_dispatcher_chat_with_contact_id (
-				connection, priv->id, EMPATHY_DISPATCHER_NON_USER_ACTION,
-				NULL, NULL);
+				account, priv->id, TP_USER_ACTION_TIME_NOT_USER_ACTION);
 			break;
 		case TP_HANDLE_TYPE_ROOM:
-			empathy_dispatcher_join_muc (connection,
-				priv->id, EMPATHY_DISPATCHER_NON_USER_ACTION);
+			empathy_dispatcher_join_muc (account, priv->id,
+				TP_USER_ACTION_TIME_NOT_USER_ACTION);
 			break;
+		case TP_HANDLE_TYPE_NONE:
+		case TP_HANDLE_TYPE_LIST:
+		case TP_HANDLE_TYPE_GROUP:
 		default:
 			g_assert_not_reached ();
 			break;
 	}
 
-out:
 	g_object_unref (chat);
 }
 
@@ -287,8 +284,8 @@ chat_new_connection_cb (TpAccount   *account,
 		return;
 
 	g_object_ref (chat);
-	tp_connection_call_when_ready (connection, reconnected_connection_ready_cb,
-				   chat);
+
+	account_reconnected (chat, account);
 }
 
 static void
@@ -632,6 +629,7 @@ typedef struct {
 	gchar *message;
 } ChatCommandMsgData;
 
+#if 0
 static void
 chat_command_msg_cb (EmpathyDispatchOperation *dispatch,
 			      const GError             *error,
@@ -661,6 +659,7 @@ OUT:
 	g_free (data->message);
 	g_slice_free (ChatCommandMsgData, data);
 }
+#endif
 
 static void
 chat_command_clear (EmpathyChat *chat,
@@ -714,14 +713,15 @@ chat_command_join (EmpathyChat *chat,
 			TpConnection *connection;
 
 			connection = empathy_tp_chat_get_connection (priv->tp_chat);
-			empathy_dispatcher_join_muc (connection, rooms[i],
-						     gtk_get_current_event_time ());
+			empathy_dispatcher_join_muc (priv->account, rooms[i],
+				gtk_get_current_event_time ());
 		}
 		i++;
 	}
 	g_strfreev (rooms);
 }
 
+#if 0
 static void
 chat_command_msg_internal (EmpathyChat *chat,
 			   const gchar *contact_id,
@@ -758,6 +758,7 @@ chat_command_msg (EmpathyChat *chat,
 {
 	chat_command_msg_internal (chat, strv[1], strv[2]);
 }
+#endif
 
 static void
 chat_command_nick (EmpathyChat *chat,
@@ -829,11 +830,14 @@ static ChatCommandItem commands[] = {
 	{"j", 2, 2, chat_command_join,
 	 N_("/j <chat room ID>: join a new chat room")},
 
+#if 0
+/* FIXME: https://bugzilla.gnome.org/show_bug.cgi?id=623682 */
 	{"query", 2, 3, chat_command_query,
 	 N_("/query <contact ID> [<message>]: open a private chat")},
 
 	{"msg", 3, 3, chat_command_msg,
 	 N_("/msg <contact ID> <message>: open a private chat")},
+#endif
 
 	{"nick", 2, 2, chat_command_nick,
 	 N_("/nick <nickname>: change your nickname on the current server")},
@@ -1112,7 +1116,7 @@ chat_message_received (EmpathyChat *chat, EmpathyMessage *message)
 	sender = empathy_message_get_sender (message);
 
 	DEBUG ("Appending new message from %s (%d)",
-		empathy_contact_get_name (sender),
+		empathy_contact_get_alias (sender),
 		empathy_contact_get_handle (sender));
 
 	empathy_chat_view_append_message (chat->view, message);
@@ -1159,6 +1163,7 @@ chat_send_error_cb (EmpathyTpChat          *tp_chat,
 	case TP_CHANNEL_TEXT_SEND_ERROR_NOT_IMPLEMENTED:
 		error = _("not implemented");
 		break;
+	case TP_CHANNEL_TEXT_SEND_ERROR_UNKNOWN:
 	default:
 		error = _("unknown");
 		break;
@@ -1593,7 +1598,7 @@ chat_input_key_press_event_cb (GtkWidget   *widget,
 				 * which might be cased all wrong.
 				 * Fixes #120876
 				 * */
-				text = empathy_contact_get_name (completed_list->data);
+				text = empathy_contact_get_alias (completed_list->data);
 			} else {
 				text = completed;
 
@@ -1603,7 +1608,7 @@ chat_input_key_press_event_cb (GtkWidget   *widget,
 				 * */
 				 message = g_string_new ("");
 				 for (l = completed_list; l != NULL; l = l->next) {
-					g_string_append (message, empathy_contact_get_name (l->data));
+					g_string_append (message, empathy_contact_get_alias (l->data));
 					g_string_append (message, " - ");
 				 }
 				 empathy_chat_view_append_event (chat->view, message->str);
@@ -2050,7 +2055,7 @@ build_part_message (guint           reason,
 	const gchar *actor_name = NULL;
 
 	if (actor != NULL) {
-		actor_name = empathy_contact_get_name (actor);
+		actor_name = empathy_contact_get_alias (actor);
 	}
 
 	/* Having an actor only really makes sense for a few actions... */
@@ -2106,7 +2111,7 @@ chat_members_changed_cb (EmpathyTpChat  *tp_chat,
 			 EmpathyChat    *chat)
 {
 	EmpathyChatPriv *priv = GET_PRIV (chat);
-	const gchar *name = empathy_contact_get_name (contact);
+	const gchar *name = empathy_contact_get_alias (contact);
 	gchar *str;
 
 	g_return_if_fail (TP_CHANNEL_GROUP_CHANGE_REASON_RENAMED != reason);
@@ -2141,8 +2146,8 @@ chat_member_renamed_cb (EmpathyTpChat  *tp_chat,
 		gchar *str;
 
 		str = g_strdup_printf (_("%s is now known as %s"),
-				       empathy_contact_get_name (old_contact),
-				       empathy_contact_get_name (new_contact));
+				       empathy_contact_get_alias (old_contact),
+				       empathy_contact_get_alias (new_contact));
 		empathy_chat_view_append_event (chat->view, str);
 		g_free (str);
 	}
@@ -2289,6 +2294,7 @@ static gboolean
 update_misspelled_words (gpointer data)
 {
 	EmpathyChat *chat = EMPATHY_CHAT (data);
+	EmpathyChatPriv *priv = GET_PRIV (chat);
 	GtkTextBuffer *buffer;
 	GtkTextIter iter;
 	gint length;
@@ -2299,6 +2305,9 @@ update_misspelled_words (gpointer data)
 	length = gtk_text_iter_get_offset (&iter);
 	chat_input_text_buffer_insert_text_cb (buffer, &iter,
 					       NULL, length, chat);
+
+	priv->update_misspelled_words_id = 0;
+
 	return FALSE;
 }
 
@@ -2329,7 +2338,8 @@ conf_spell_checking_cb (GSettings *gsettings_chat,
 			/* Possibly changed dictionaries,
 			 * update misspelled words. Need to do so in idle
 			 * so the spell checker is updated. */
-			g_idle_add (update_misspelled_words, chat);
+			priv->update_misspelled_words_id =
+				g_idle_add (update_misspelled_words, chat);
 		}
 
 		return;
@@ -2362,7 +2372,8 @@ conf_spell_checking_cb (GSettings *gsettings_chat,
 
 		/* Mark misspelled words in the existing buffer.
 		 * Need to do so in idle so the spell checker is updated. */
-		g_idle_add (update_misspelled_words, chat);
+		priv->update_misspelled_words_id =
+			g_idle_add (update_misspelled_words, chat);
 	} else {
 		GtkTextTagTable *table;
 		GtkTextTag *tag;
@@ -2581,6 +2592,9 @@ chat_finalize (GObject *object)
 
 	DEBUG ("Finalized: %p", object);
 
+	if (priv->update_misspelled_words_id != 0)
+		g_source_remove (priv->update_misspelled_words_id);
+
 	g_object_unref (priv->gsettings_chat);
 	g_object_unref (priv->gsettings_ui);
 
@@ -2810,7 +2824,7 @@ empathy_chat_init (EmpathyChat *chat)
 		g_timeout_add_seconds (1, chat_block_events_timeout_cb, chat);
 
 	/* Add nick name completion */
-	priv->completion = g_completion_new ((GCompletionFunc) empathy_contact_get_name);
+	priv->completion = g_completion_new ((GCompletionFunc) empathy_contact_get_alias);
 	g_completion_set_compare (priv->completion, chat_contacts_completion_func);
 
 	chat_create_ui (chat);
@@ -3010,7 +3024,7 @@ empathy_chat_set_tp_chat (EmpathyChat   *chat,
 
 	priv->tp_chat = g_object_ref (tp_chat);
 	connection = empathy_tp_chat_get_connection (priv->tp_chat);
-	priv->account = g_object_ref (empathy_get_account_for_connection (connection));
+	priv->account = g_object_ref (empathy_tp_chat_get_account (priv->tp_chat));
 
 	g_signal_connect (tp_chat, "destroy",
 			  G_CALLBACK (chat_destroy_cb),
@@ -3111,7 +3125,7 @@ empathy_chat_get_name (EmpathyChat *chat)
 
 	ret = priv->name;
 	if (!ret && priv->remote_contact) {
-		ret = empathy_contact_get_name (priv->remote_contact);
+		ret = empathy_contact_get_alias (priv->remote_contact);
 	}
 
 	if (!ret)
@@ -3230,6 +3244,11 @@ empathy_chat_paste (EmpathyChat *chat)
 
 	priv = GET_PRIV (chat);
 
+	if (gtk_widget_get_visible (priv->search_bar)) {
+		empathy_search_bar_paste_clipboard (EMPATHY_SEARCH_BAR (priv->search_bar));
+		return;
+	}
+
 	if (priv->tp_chat == NULL ||
 	    !gtk_widget_is_sensitive (chat->input_text_view))
 		return;
