@@ -350,15 +350,18 @@ details_feature_prepared_cb (TpConnection *connection,
     DetailsData *data)
 {
   EmpathyIndividualWidget *self = data->widget;
-  EmpathyIndividualWidgetPriv *priv = GET_PRIV (self);
+  EmpathyIndividualWidgetPriv *priv = NULL;
 
-  if (tp_proxy_prepare_finish (connection, res, NULL) == FALSE)
+  if (tp_proxy_prepare_finish (connection, res, NULL) == FALSE || self == NULL)
     {
-      gtk_widget_hide (priv->vbox_details);
+      if (self != NULL)
+        gtk_widget_hide (GET_PRIV (self)->vbox_details);
       details_data_free (data);
       return;
     }
 
+  priv = GET_PRIV (self);
+
   /* Request the Individual's info */
   gtk_widget_show (priv->vbox_details);
   gtk_widget_show (priv->hbox_details_requested);
@@ -530,7 +533,8 @@ location_update (EmpathyIndividualWidget *self)
   gboolean display_map = FALSE;
   GList *personas, *l;
 
-  if (!(priv->flags & EMPATHY_INDIVIDUAL_WIDGET_SHOW_LOCATION))
+  if (!(priv->flags & EMPATHY_INDIVIDUAL_WIDGET_SHOW_LOCATION) ||
+      priv->individual == NULL)
     {
       gtk_widget_hide (priv->vbox_location);
       return;
@@ -1676,6 +1680,8 @@ personas_changed_cb (FolksIndividual *individual,
       /* Remove all Personas */
       for (l = personas; l != NULL; l = l->next)
         remove_persona (self, FOLKS_PERSONA (l->data));
+      for (l = removed; l != NULL; l = l->next)
+        remove_persona (self, FOLKS_PERSONA (l->data));
 
       /* Set up the Individual table instead */
       individual_table_set_up (self);
@@ -1698,6 +1704,14 @@ personas_changed_cb (FolksIndividual *individual,
   g_list_free (children);
 }
 
+static void
+individual_removed_cb (FolksIndividual *individual,
+    FolksIndividual *replacement_individual,
+    EmpathyIndividualWidget *self)
+{
+  empathy_individual_widget_set_individual (self, replacement_individual);
+}
+
 static void
 remove_individual (EmpathyIndividualWidget *self)
 {
@@ -1714,6 +1728,8 @@ remove_individual (EmpathyIndividualWidget *self)
           notify_avatar_cb, self);
       g_signal_handlers_disconnect_by_func (priv->individual,
           personas_changed_cb, self);
+      g_signal_handlers_disconnect_by_func (priv->individual,
+          individual_removed_cb, self);
 
       if (priv->flags & EMPATHY_INDIVIDUAL_WIDGET_EDIT_FAVOURITE)
         {
@@ -1760,6 +1776,8 @@ individual_update (EmpathyIndividualWidget *self)
           (GCallback) notify_avatar_cb, self);
       g_signal_connect (priv->individual, "personas-changed",
           (GCallback) personas_changed_cb, self);
+      g_signal_connect (priv->individual, "removed",
+          (GCallback) individual_removed_cb, self);
 
       if (priv->flags & EMPATHY_INDIVIDUAL_WIDGET_EDIT_FAVOURITE)
         {
